package org.example;

import jakarta.jms.JMSException;
import jakarta.jms.Message;
import jakarta.jms.Session;
import jakarta.jms.TextMessage;
import org.springframework.jms.support.converter.MessageConversionException;
import org.springframework.jms.support.converter.MessageConverter;
import org.springframework.stereotype.Component;

//@Component
public class ChatMessageCsvConverter implements MessageConverter {

	private static final String CSV_DELIMITER = ",";

	@Override
	public Message toMessage(Object object, Session session) throws JMSException, MessageConversionException {
		if (object instanceof ChatMessage chatMessage) {
			String content = chatMessage.user() + CSV_DELIMITER + chatMessage.text();
			return session.createTextMessage(content);
		} else throw new MessageConversionException("Invalid message type: " + object.getClass().getName());
	}

	@Override
	public Object fromMessage(Message message) throws JMSException, MessageConversionException {
		if (message instanceof TextMessage textMessage) {
			String content = textMessage.getText();
			String[] tokens = content.split(CSV_DELIMITER);
			if (tokens.length < 2) {
				throw new MessageConversionException("Invalid message format: " + content);
			}
			return new ChatMessage(tokens[0], tokens[1]);
		} else throw new MessageConversionException("Invalid message type: " + message.getClass().getName());
	}
}
